@@ -1,6 +1,6 @@
 """Interfaces/Adapters to the used machine learning framework"""
 
-from typing import Iterable, Protocol, runtime_checkable
+from typing import Any, Callable, Iterable, Iterator, Protocol, runtime_checkable
 
 from numpy.typing import ArrayLike
 
@@ -11,6 +11,9 @@ class Tensor(Protocol):
     def __getitem__(self, index: Index) -> "Tensor":
         ...
 
+    def apply_(self, callable: Callable) -> "Tensor":
+        ...
+
     def detach(self) -> "Tensor":
         ...
 
@@ -18,6 +21,11 @@ class Tensor(Protocol):
         ...
 
 
+@runtime_checkable
+class Parameter(Tensor, Protocol):
+    ...
+
+
 @runtime_checkable
 class Module(Protocol):
     @property
@@ -30,5 +38,11 @@ class Module(Protocol):
     def named_children(self) -> Iterable[tuple[str, "Module"]]:
         ...
 
-    def __call__(self, x: Tensor, *args, **kwargs) -> Tensor:
+    def parameters(self, recurse: bool = True) -> Iterator[Parameter]:
+        ...
+
+    def state_dict(self) -> dict[str, Any]:
+        ...
+
+    def __call__(self, x: Any, *args: Any, **kwargs: Any) -> Any:
         ...
