@@ -1,7 +1,6 @@
 import subprocess
 
 from elasticai.creator.resource_utils import get_full_path
-from elasticai.creator.vhdl import vhdl_formatter
 
 """
     we are using vsg (VHDL Style Guide) for indenting the generated vhdl files
@@ -12,11 +11,9 @@ from elasticai.creator.vhdl import vhdl_formatter
 """
 
 
-def format_vhdl(file_path):
-    # get the path of config
-    config_path = get_full_path(package=vhdl_formatter, file_name="config.json")
-    # check if the vhdl file exist !
-    subprocess.Popen(
+def format_vhdl(file_path: str):
+    config_path = get_full_path("elasticai.creator.vhdl.vhdl_formatter", "config.json")
+    subprocess.run(
         f"vsg -f {file_path} --style indent_only --configuration {config_path} --fix",
         shell=True,
     )
